<?php

namespace Testapp\ClientDetail\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Form;
use Testapp\ClientDetail\Http\Requests\ClientDetailAdminRequest;
use Testapp\ClientDetail\Interfaces\ClientDetailRepositoryInterface;
use Testapp\ClientDetail\Models\ClientDetail;

/**
 * Admin controller class.
 */
class ClientDetailAdminController extends AdminController
{
    /**
     * Initialize client_detail controller.
     *
     * @param type ClientDetailRepositoryInterface $client_detail
     *
     * @return type
     */
    public function __construct(ClientDetailRepositoryInterface $client_detail)
    {
        parent::__construct();
        $this->repository = $client_detail;
    }

    /**
     * Display a list of client_detail.
     *
     * @return Response
     */
    public function index(ClientDetailAdminRequest $request)
    {
        $client_details  = $this->repository->setPresenter('\\Testapp\\ClientDetail\\Repositories\\Presenter\\ClientDetailListPresenter')
                                            ->scopeQuery(function($query){
                                                return $query->orderBy('id','DESC');
                                            })->paginate();
        $this   ->theme->prependTitle(trans('client_detail::client_detail.names').' :: ');
        $view   = $this->theme->of('client_detail::admin.client_detail.index')->render();

        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('client_detail::client_detail.name')]);
        $this->responseData = $client_details['data'];
        $this->responseMeta = $client_details['meta'];
        $this->responseView = $view;
        $this->responseRedirect = '';
        return $this->respond($request);
    }

    /**
     * Display client_detail.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ClientDetailAdminRequest $request, ClientDetail $client_detail)
    {
        if (!$client_detail->exists) {
            $this->responseCode = 404;
            $this->responseMessage = trans('messages.success.notfound', ['Module' => trans('client_detail::client_detail.name')]);
            $this->responseView = view('client_detail::admin.client_detail.new');
            return $this -> respond($request);
        }

        Form::populate($client_detail);
        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('client_detail::client_detail.name')]);
        $this->responseData = $client_detail;
        $this->responseView = view('client_detail::admin.client_detail.show', compact('client_detail'));
        return $this -> respond($request);
    }

    /**
     * Show the form for creating a new client_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ClientDetailAdminRequest $request)
    {

        $client_detail = $this->repository->newInstance([]);

        Form::populate($client_detail);

        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('client_detail::client_detail.name')]);
        $this->responseData = $client_detail;
        $this->responseView = view('client_detail::admin.client_detail.create', compact('client_detail'));
        return $this -> respond($request);

    }

    /**
     * Create new client_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ClientDetailAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $client_detail = $this->repository->create($attributes);

            $this->responseCode = 201;
            $this->responseMessage = trans('messages.success.created', ['Module' => trans('client_detail::client_detail.name')]);
            $this->responseData = $client_detail;
            $this->responseMeta = '';
            $this->responseRedirect = trans_url('/admin/client_detail/client_detail/'.$client_detail->getRouteKey());
            $this->responseView = view('client_detail::admin.client_detail.create', compact('client_detail'));

            return $this -> respond($request);

        } catch (Exception $e) {
            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            return $this -> respond($request);
        }
    }

    /**
     * Show client_detail for editing.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ClientDetailAdminRequest $request, ClientDetail $client_detail)
    {
        Form::populate($client_detail);
        $this->responseCode = 200;
        $this->responseMessage = trans('messages.success.loaded', ['Module' => trans('client_detail::client_detail.name')]);
        $this->responseData = $client_detail;
        $this->responseView = view('client_detail::admin.client_detail.edit', compact('client_detail'));

        return $this -> respond($request);
    }

    /**
     * Update the client_detail.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ClientDetailAdminRequest $request, ClientDetail $client_detail)
    {
        try {

            $attributes = $request->all();

            $client_detail->update($attributes);

            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.updated', ['Module' => trans('client_detail::client_detail.name')]);
            $this->responseData = $client_detail;
            $this->responseRedirect = trans_url('/admin/client_detail/client_detail/'.$client_detail->getRouteKey());

            return $this -> respond($request);

        } catch (Exception $e) {

            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            $this->responseRedirect = trans_url('/admin/client_detail/client_detail/'.$client_detail->getRouteKey());

            return $this -> respond($request);
        }
    }

    /**
     * Remove the client_detail.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ClientDetailAdminRequest $request, ClientDetail $client_detail)
    {

        try {

            $t = $client_detail->delete();

            $this->responseCode = 202;
            $this->responseMessage = trans('messages.success.deleted', ['Module' => trans('client_detail::client_detail.name')]);
            $this->responseRedirect = trans_url('/admin/client_detail/client_detail/0');

            return $this -> respond($request);

        } catch (Exception $e) {

            $this->responseCode = 400;
            $this->responseMessage = $e->getMessage();
            $this->responseRedirect = trans_url('/admin/client_detail/client_detail/'.$client_detail->getRouteKey());

            return $this -> respond($request);

        }
    }
}
