<?php

namespace Testapp\ClientDetail\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Form;
use Testapp\ClientDetail\Http\Requests\ClientDetailUserRequest;
use Testapp\ClientDetail\Interfaces\ClientDetailRepositoryInterface;
use Testapp\ClientDetail\Models\ClientDetail;

class ClientDetailUserController extends UserController
{
    /**
     * Initialize client_detail controller.
     *
     * @param type ClientDetailRepositoryInterface $client_detail
     *
     * @return type
     */
    public function __construct(ClientDetailRepositoryInterface $client_detail)
    {
        $this->repository = $client_detail;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ClientDetailUserRequest $request)
    {
        $this->repository->pushCriteria(new \Lavalite\ClientDetail\Repositories\Criteria\ClientDetailUserCriteria());
        $client_details = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('client_detail::client_detail.names').' :: ');

        return $this->theme->of('client_detail::user.client_detail.index', compact('client_details'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param ClientDetail $client_detail
     *
     * @return Response
     */
    public function show(ClientDetailUserRequest $request, ClientDetail $client_detail)
    {
        Form::populate($client_detail);

        return $this->theme->of('client_detail::user.client_detail.show', compact('client_detail'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ClientDetailUserRequest $request)
    {

        $client_detail = $this->repository->newInstance([]);
        Form::populate($client_detail);

        return $this->theme->of('client_detail::user.client_detail.create', compact('client_detail'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ClientDetailUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $client_detail = $this->repository->create($attributes);

            $this->responseCode = 201;
            $this->responseMessage = trans('messages.success.created', ['Module' => trans('client_detail::client_detail.name')]);
            $this->responseRedirect = trans_url('/user/client_detail/client_detail');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param ClientDetail $client_detail
     *
     * @return Response
     */
    public function edit(ClientDetailUserRequest $request, ClientDetail $client_detail)
    {

        Form::populate($client_detail);

        return $this->theme->of('client_detail::user.client_detail.edit', compact('client_detail'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param ClientDetail $client_detail
     *
     * @return Response
     */
    public function update(ClientDetailUserRequest $request, ClientDetail $client_detail)
    {
        try {
            $this->repository->update($request->all(), $client_detail->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.updated', ['Module' => trans('client_detail::client_detail.name')]);
            $this->responseRedirect = trans_url('/user/client_detail/client_detail');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ClientDetailUserRequest $request, ClientDetail $client_detail)
    {
        try {
            $this->repository->delete($client_detail->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.deleted', ['Module' => trans('client_detail::client_detail.name')]);
            $this->responseRedirect = trans_url('/user/client_detail/client_detail');
            return $this -> respond($request);
        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
