<?php

namespace Testapp\ClientDetail\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Testapp\ClientDetail\Models\ClientDetail;

class ClientDetailPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the client_detail.
     *
     * @param User $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function view(User $user, ClientDetail $client_detail)
    {
        if ($user->canDo('client_detail.client_detail.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $client_detail->user_id;
    }

    /**
     * Determine if the given user can create a client_detail.
     *
     * @param User $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('client_detail.client_detail.create');
    }

    /**
     * Determine if the given user can update the given client_detail.
     *
     * @param User $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function update(User $user, ClientDetail $client_detail)
    {
        if ($user->canDo('client_detail.client_detail.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $client_detail->user_id;
    }

    /**
     * Determine if the given user can delete the given client_detail.
     *
     * @param User $user
     * @param ClientDetail $client_detail
     *
     * @return bool
     */
    public function destroy(User $user, ClientDetail $client_detail)
    {
        if ($user->canDo('client_detail.client_detail.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $client_detail->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
